@@ -74,14 +74,14 @@ class AppSetup(Controller):
             backend_docker_tag = f'{plugin_name}:backend'
             frontend_docker_tag = f'{plugin_name}:frontend'
 
-            os.system(f'cd {backend}')
+            # os.system(f'cd {backend}')
             # os.system(f'docker rm $(docker stop $(docker ps -a -q --filter ancestor={backend_docker_tag} --format="{{.ID}}"))')
-            os.system(f'docker build -t {backend_docker_tag} .')
+            os.system(f'cd {backend} && docker build -t {backend_docker_tag} .')
             os.system(f'docker run -it -p 5000:5000 -d {backend_docker_tag}')
 
-            os.system(f'cd {frontend}')
+            # os.system(f'cd {frontend}')
             # os.system(f'docker rm $(docker stop $(docker ps -a -q --filter ancestor={frontend_docker_tag} --format="{{.ID}}"))')
-            os.system(f'docker build -t {frontend_docker_tag} .')
+            os.system(f'cd {frontend} && docker build -t {frontend_docker_tag} .')
             os.system(f'docker run -it -p 3000:3000 -d {frontend_docker_tag}')
 
         except OSError as e:
